@@ -14,7 +14,7 @@ from traitlets import Instance, Unicode, Bytes, Bool, Dict, Any, default
 
 class Comm(LoggingConfigurable):
     """Class for communicating between a Frontend and a Kernel"""
-    kernel = Instance('ipykernel.kernelbase.Kernel')
+    kernel = Instance('ipykernel.kernelbase.Kernel', allow_none=True)
 
     @default('kernel')
     def _default_kernel(self):
@@ -51,7 +51,7 @@ class Comm(LoggingConfigurable):
         if target_name:
             kwargs['target_name'] = target_name
         super(Comm, self).__init__(**kwargs)
-        if self.primary:
+        if self.kernel is not None and self.primary:
             # I am primary, open my peer.
             self.open(data=data, metadata=metadata, buffers=buffers)
         else:
